/*
   SPDX-FileCopyrightText: 2014-2024 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/
#include "knoteinterface.h"

KNoteInterface::KNoteInterface()
{
}

void KNoteInterface::setBlockSave(bool b)
{
    mBlockSave = b;
}
